openvm-cuda-common 2.0.0

CUDA common utils
docs.rs failed to build openvm-cuda-common-2.0.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.